@@ -2,21 +2,23 @@
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qdarwinaudiodevices_p.h"
-#include "qmediadevices.h"
-#include "private/qaudiodevice_p.h"
-#include "qdarwinaudiodevice_p.h"
-#include "qdarwinaudiosource_p.h"
-#include "qdarwinaudiosink_p.h"
 
-#include <qloggingcategory.h>
+#include <QtMultimedia/qmediadevices.h>
+#include <QtMultimedia/private/qaudiodevice_p.h>
+#include <QtMultimedia/private/qdarwinaudiodevice_p.h>
+#include <QtMultimedia/private/qdarwinaudiosink_p.h>
+#include <QtMultimedia/private/qdarwinaudiosource_p.h>
 
-#include <qdebug.h>
+#include <QtCore/qcoreapplication.h>
+#include <QtCore/qloggingcategory.h>
+#include <QtCore/qdebug.h>
 
 #if defined(QT_PLATFORM_UIKIT)
-#include "qcoreaudiosessionmanager_p.h"
-#import <AVFoundation/AVFoundation.h>
+#  include <QtMultimedia/private/qcoreaudiosessionmanager_p.h>
+#  import <AVFoundation/AVFoundation.h>
 #else
-#include "qmacosaudiodatautils_p.h"
+
+#  include <QtMultimedia/private/qmacosaudiodatautils_p.h>
 #endif
 
 #if defined(Q_OS_MACOS)
@@ -25,8 +27,8 @@ Q_STATIC_LOGGING_CATEGORY(qLcDarwinMediaDevices, "qt.multimedia.darwin.mediaDevi
 
 QT_BEGIN_NAMESPACE
 
-template<typename... Args>
-QAudioDevice createAudioDevice(bool isDefault, Args &&...args)
+template <typename... Args>
+static QAudioDevice createAudioDevice(bool isDefault, Args &&...args)
 {
     auto dev = std::make_unique<QCoreAudioDeviceInfo>(std::forward<Args>(args)...);
     dev->isDefault = isDefault;
@@ -37,8 +39,9 @@ QAudioDevice createAudioDevice(bool isDefault, Args &&...args)
 
 static AudioDeviceID defaultAudioDevice(QAudioDevice::Mode mode)
 {
-    const AudioObjectPropertySelector selector = (mode == QAudioDevice::Output) ? kAudioHardwarePropertyDefaultOutputDevice
-                                                                               : kAudioHardwarePropertyDefaultInputDevice;
+    const AudioObjectPropertySelector selector = (mode == QAudioDevice::Output)
+            ? kAudioHardwarePropertyDefaultOutputDevice
+            : kAudioHardwarePropertyDefaultInputDevice;
     const AudioObjectPropertyAddress propertyAddress = {
         selector,
         kAudioObjectPropertyScopeGlobal,
@@ -94,69 +97,6 @@ static QList<QAudioDevice> availableAudioDevices(QAudioDevice::Mode mode)
     return devices;
 }
 
-static OSStatus audioDeviceChangeListener(AudioObjectID id, UInt32,
-                                          const AudioObjectPropertyAddress *address, void *ptr)
-{
-    Q_ASSERT(address);
-    Q_ASSERT(ptr);
-
-    QDarwinAudioDevices *instance = static_cast<QDarwinAudioDevices *>(ptr);
-
-    qCDebug(qLcDarwinMediaDevices)
-            << "audioDeviceChangeListener: id:" << id << "address: " << address->mSelector
-            << address->mScope << address->mElement;
-
-    switch (address->mSelector) {
-    case kAudioHardwarePropertyDefaultInputDevice:
-        instance->updateAudioInputsCache();
-        break;
-    case kAudioHardwarePropertyDefaultOutputDevice:
-        instance->updateAudioOutputsCache();
-        break;
-    default:
-        instance->updateAudioInputsCache();
-        instance->updateAudioOutputsCache();
-        break;
-    }
-
-    return 0;
-}
-
-static constexpr AudioObjectPropertyAddress listenerAddresses[] = {
-    { kAudioHardwarePropertyDefaultInputDevice, kAudioObjectPropertyScopeGlobal,
-      kAudioObjectPropertyElementMain },
-    { kAudioHardwarePropertyDefaultOutputDevice, kAudioObjectPropertyScopeGlobal,
-      kAudioObjectPropertyElementMain },
-    { kAudioHardwarePropertyDevices, kAudioObjectPropertyScopeGlobal,
-      kAudioObjectPropertyElementMain }
-};
-
-static void setAudioListeners(QDarwinAudioDevices &instance)
-{
-    for (const auto &address : listenerAddresses) {
-        const auto err = AudioObjectAddPropertyListener(kAudioObjectSystemObject, &address,
-                                                        audioDeviceChangeListener, &instance);
-
-        if (err)
-            qWarning() << "Fail to add listener. mSelector:" << address.mSelector
-                       << "mScope:" << address.mScope << "mElement:" << address.mElement
-                       << "err:" << err;
-    }
-}
-
-static void removeAudioListeners(QDarwinAudioDevices &instance)
-{
-    for (const auto &address : listenerAddresses) {
-        const auto err = AudioObjectRemovePropertyListener(kAudioObjectSystemObject, &address,
-                                                           audioDeviceChangeListener, &instance);
-
-        if (err)
-            qWarning() << "Fail to remove listener. mSelector:" << address.mSelector
-                       << "mScope:" << address.mScope << "mElement:" << address.mElement
-                       << "err:" << err;
-    }
-}
-
 #elif defined(QT_PLATFORM_UIKIT)
 
 static QList<QAudioDevice> availableAudioDevices(QAudioDevice::Mode mode)
@@ -191,32 +131,97 @@ static QList<QAudioDevice> availableAudioDevices(QAudioDevice::Mode mode)
     return devices;
 }
 
-static void setAudioListeners(QDarwinAudioDevices &)
-{
-    // ### This should use the audio session manager
-}
+#endif
 
-static void removeAudioListeners(QDarwinAudioDevices &)
-{
-    // ### This should use the audio session manager
-}
+#ifdef Q_OS_MACOS
+
+static constexpr AudioObjectPropertyAddress listenerAddresses[] = {
+    { kAudioHardwarePropertyDefaultInputDevice, kAudioObjectPropertyScopeGlobal,
+      kAudioObjectPropertyElementMain },
+    { kAudioHardwarePropertyDefaultOutputDevice, kAudioObjectPropertyScopeGlobal,
+      kAudioObjectPropertyElementMain },
+    { kAudioHardwarePropertyDevices, kAudioObjectPropertyScopeGlobal,
+      kAudioObjectPropertyElementMain }
+};
 
 #endif
 
 QDarwinAudioDevices::QDarwinAudioDevices()
 {
-#ifdef Q_OS_MACOS // TODO: implement setAudioListeners, removeAudioListeners for Q_OS_IOS, after
-                  // that - remove or modify the define
+    if (!QThread::isMainThread())
+        moveToThread(qApp->thread());
+
+#ifdef Q_OS_MACOS
+    m_listenerQueue.reset(
+            dispatch_queue_create("QtAudioDevicesListener", /*dispatch_queue_attr=*/nullptr));
+    dispatch_set_target_queue(m_listenerQueue.get(), dispatch_get_main_queue());
+
+    std::shared_ptr destroyedFlag = m_destroyed; // capture shared_ptr
+    m_deviceListenerBlock = std::make_unique<AudioObjectPropertyListenerBlock>(
+            [this, destroyedFlag](UInt32 numberOfProps, const AudioObjectPropertyAddress *props) {
+        // the block is dispatched via a dispatch queue on the main thread and can be in-flight when
+        // the QDarwinAudioDevices instance is being destroyed. Check the destroyed flag to avoid
+        // accessing deleted memory.
+        if (*destroyedFlag)
+            return;
+
+        Q_ASSERT(QThread::isMainThread());
+
+        auto properties = QSpan{ props, numberOfProps };
+
+        bool updateInputs = false;
+        bool updateOutputs = false;
+
+        for (const AudioObjectPropertyAddress &address : properties) {
+            qCDebug(qLcDarwinMediaDevices)
+                    << "audioDeviceChangeListenerBlock: address: " << address.mSelector
+                    << address.mScope << address.mElement;
+
+            switch (address.mSelector) {
+            case kAudioHardwarePropertyDefaultInputDevice:
+                updateInputs = true;
+                break;
+            case kAudioHardwarePropertyDefaultOutputDevice:
+                updateOutputs = true;
+                break;
+            default:
+                updateInputs = true;
+                updateOutputs = true;
+                break;
+            }
+        }
+
+        if (updateInputs)
+            updateAudioInputsCache();
+        if (updateOutputs)
+            updateAudioOutputsCache();
+    });
+
+    for (const auto &address : listenerAddresses) {
+        const auto err = AudioObjectAddPropertyListenerBlock(
+                kAudioObjectSystemObject, &address, m_listenerQueue.get(), *m_deviceListenerBlock);
+        if (err)
+            qWarning() << "Fail to add listener. mSelector:" << address.mSelector
+                       << "mScope:" << address.mScope << "mElement:" << address.mElement
+                       << "err:" << err;
+    }
+
     updateAudioInputsCache();
     updateAudioOutputsCache();
 #endif
-
-    setAudioListeners(*this);
 }
 
 QDarwinAudioDevices::~QDarwinAudioDevices()
 {
-    removeAudioListeners(*this);
+#ifdef Q_OS_MACOS
+    *m_destroyed = true;
+    for (const auto &address : listenerAddresses) {
+        Q_ASSERT(m_deviceListenerBlock);
+        AudioObjectRemovePropertyListenerBlock(kAudioObjectSystemObject, &address,
+                                               m_listenerQueue.get(), *m_deviceListenerBlock);
+    }
+    m_listenerQueue = {};
+#endif
 }
 
 QList<QAudioDevice> QDarwinAudioDevices::findAudioInputs() const
@@ -242,4 +247,70 @@ QPlatformAudioSink *QDarwinAudioDevices::createAudioSink(const QAudioDevice &inf
     return new QDarwinAudioSink(info, fmt, parent);
 }
 
+namespace QCoreAudioUtils {
+
+#ifdef Q_OS_MACOS
+
+static constexpr AudioObjectPropertyAddress propertyAddressDeviceIsAlive = {
+    kAudioDevicePropertyDeviceIsAlive,
+    kAudioObjectPropertyScopeGlobal,
+    kAudioObjectPropertyElementMain,
+};
+
+// force dtor in a translation unit with ARC enabled
+DeviceDisconnectMonitor::~DeviceDisconnectMonitor()
+{
+    Q_ASSERT(!m_disconnectFunction);
+}
+
+std::optional<QFuture<void>> DeviceDisconnectMonitor::addDisconnectListener(AudioObjectID id)
+{
+    Q_ASSERT(!m_disconnectFunction);
+
+    auto disconnectedPromise = std::make_shared<QPromise<void>>();
+    QFuture<void> disconnectFuture = disconnectedPromise->future();
+
+    auto listenerBlock = std::make_shared<AudioObjectPropertyListenerBlock>(
+            [disconnectedPromise](UInt32 numberOfProps, const AudioObjectPropertyAddress *props) {
+        // Called on HAL thread
+        auto properties = QSpan{ props, numberOfProps };
+
+        for (const AudioObjectPropertyAddress &address : properties) {
+            if (address.mSelector == kAudioDevicePropertyDeviceIsAlive) {
+                disconnectedPromise->start();
+                disconnectedPromise->finish();
+                return;
+            }
+        }
+    });
+
+    OSStatus status =
+            AudioObjectAddPropertyListenerBlock(id, &propertyAddressDeviceIsAlive,
+                                                /*inDispatchQueue=*/nullptr, *listenerBlock);
+
+    if (status != noErr) {
+        qWarning() << "QAudioOutput: Failed to add property listener";
+        return std::nullopt;
+    }
+
+    m_disconnectFunction = [id, listenerBlock] {
+        AudioObjectRemovePropertyListenerBlock(id, &propertyAddressDeviceIsAlive,
+                                               /*inDispatchQueue=*/nullptr, *listenerBlock);
+    };
+
+    return disconnectFuture;
+}
+
+void DeviceDisconnectMonitor::removeDisconnectListener()
+{
+    if (!m_disconnectFunction)
+        return;
+    m_disconnectFunction();
+    m_disconnectFunction = nullptr;
+}
+
+#endif
+
+} // namespace QCoreAudioUtils
+
 QT_END_NAMESPACE
