@@ -103,9 +103,9 @@ QQuickVideoOutput::QQuickVideoOutput(QQuickItem *parent) :
 
     // TODO: investigate if we have any benefit of setting frame in the source thread
     connect(m_sink, &QVideoSink::videoFrameChanged, this,
-            makeGuardedCall([](QQuickVideoOutput *self, const QVideoFrame &frame) {
-        if (frame.isValid() || self->m_endOfStreamPolicy == ClearOutput)
-            self->setFrame(frame);
+            makeGuardedCall([this](const QVideoFrame &frame) {
+        if (frame.isValid() || m_endOfStreamPolicy == ClearOutput)
+            setFrame(frame);
     }),
             Qt::DirectConnection);
 
@@ -118,7 +118,9 @@ QQuickVideoOutput::~QQuickVideoOutput()
         QMutexLocker lock(&m_destructorGuard->m_mutex);
         m_destructorGuard->m_isAlive = false;
     }
-    m_destructorGuard = {};
+
+    delete m_sink;
+    disconnectWindowConnections();
 }
 
 /*!
@@ -353,7 +355,7 @@ QRectF QQuickVideoOutput::contentRect() const
     The \c endOfStreamPolicy can be one of:
 
     \value ClearOutput The video output is cleared.
-    \value KeepLastFrame The video output continues displaying the 
+    \value KeepLastFrame The video output continues displaying the
            last frame. Use the method \l clearOutput() to clear the output manually.
 
     The default value is \c ClearOutput.
@@ -373,7 +375,7 @@ void QQuickVideoOutput::setEndOfStreamPolicy(EndOfStreamPolicy policy)
 }
 
 /*!
-    \qmlmethod void QtMultimedia::VideoOutput::clearOutput
+    \qmlmethod void QtMultimedia::VideoOutput::clearOutput()
     \since 6.9
 
     Clears the video output by removing the currently displayed video frame.
@@ -436,26 +438,6 @@ void QQuickVideoOutput::geometryChange(const QRectF &newGeometry, const QRectF &
     _q_updateGeometry();
 }
 
-void QQuickVideoOutput::_q_invalidateSceneGraph()
-{
-    // Invoked in the renderer thread
-
-    if (auto texturePool = m_texturePool.lock())
-        texturePool->clearTextures();
-    m_sink->setRhi(nullptr);
-}
-
-void QQuickVideoOutput::_q_sceneGraphInitialized()
-{
-    initRhiForSink();
-}
-
-void QQuickVideoOutput::_q_afterFrameEnd()
-{
-    if (auto texturePool = m_texturePool.lock())
-        texturePool->onFrameEndInvoked();
-}
-
 void QQuickVideoOutput::releaseResources()
 {
     // Called on the gui thread when the window is closed or changed.
@@ -477,27 +459,31 @@ void QQuickVideoOutput::itemChange(QQuickItem::ItemChange change,
 
     if (changeData.window == m_window)
         return;
-    if (m_window)
-        disconnect(m_window);
+
+    disconnectWindowConnections();
     m_window = changeData.window;
 
     if (m_window) {
+        auto connectToWindow = [&](auto signal, auto function) {
+            connect(m_window, signal, this, makeGuardedCall(std::move(function)),
+                    Qt::DirectConnection);
+        };
+
         // We want to receive the signals in the render thread
-        connect(m_window, &QQuickWindow::sceneGraphInitialized, this,
-                makeGuardedCall([](QQuickVideoOutput *self) {
-            self->_q_sceneGraphInitialized();
-        }),
-                Qt::DirectConnection);
-        connect(m_window, &QQuickWindow::sceneGraphInvalidated, this,
-                makeGuardedCall([](QQuickVideoOutput *self) {
-            self->_q_invalidateSceneGraph();
-        }),
-                Qt::DirectConnection);
-        connect(m_window, &QQuickWindow::afterFrameEnd, this,
-                makeGuardedCall([](QQuickVideoOutput *self) {
-            self->_q_afterFrameEnd();
-        }),
-                Qt::DirectConnection);
+        connectToWindow(&QQuickWindow::sceneGraphInitialized, [this] {
+            initRhiForSink();
+        });
+
+        connectToWindow(&QQuickWindow::sceneGraphInvalidated, [this] {
+            if (auto texturePool = m_texturePool.lock())
+                texturePool->clearTextures();
+            m_sink->setRhi(nullptr);
+        });
+
+        connectToWindow(&QQuickWindow::afterFrameEnd, [this] {
+            if (auto texturePool = m_texturePool.lock())
+                texturePool->onFrameEndInvoked();
+        });
     }
     initRhiForSink();
 }
@@ -637,6 +623,14 @@ void QQuickVideoOutput::updateHdr(QSGVideoNode *videoNode)
     videoNode->setHdrInfo(swapChain->hdrInfo());
 }
 
+void QQuickVideoOutput::disconnectWindowConnections()
+{
+    if (!m_window)
+        return;
+
+    m_window->disconnect(this);
+}
+
 QRectF QQuickVideoOutput::adjustedViewport() const
 {
     return m_videoFormat.viewport();
@@ -656,6 +650,12 @@ void QQuickVideoOutput::setFrame(const QVideoFrame &frame)
     QMetaObject::invokeMethod(this, &QQuickVideoOutput::_q_newFrame, frame.size());
 }
 
+std::optional<std::chrono::nanoseconds> QQuickVideoOutput::g_signalBackoff;
+void QQuickVideoOutput::setSignalBackoff(std::optional<std::chrono::nanoseconds> ns)
+{
+    g_signalBackoff = ns;
+}
+
 QT_END_NAMESPACE
 
 #include "moc_qquickvideooutput_p.cpp"
