@@ -116,7 +116,29 @@ q23::expected<QPlatformVideoSink *, QString> QAndroidIntegration::createVideoSin
 
 Q_DECLARE_JNI_CLASS(QtMultimediaUtils, "org/qtproject/qt/android/multimedia/QtMultimediaUtils")
 
-Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void * /*reserved*/)
+bool QAndroidIntegration::registerNativeMethods()
+{
+    static const bool result = []{
+        const auto context = QNativeInterface::QAndroidApplication::context();
+        QtJniTypes::QtMultimediaUtils::callStaticMethod<void>("setContext", context);
+
+        return AndroidCamera::registerNativeMethods()
+            && AndroidMediaRecorder::registerNativeMethods()
+            && AndroidMediaPlayer::registerNativeMethods()
+            && AndroidSurfaceHolder::registerNativeMethods()
+            && AndroidSurfaceTexture::registerNativeMethods();
+    }();
+    return result;
+}
+
+QPlatformVideoDevices *QAndroidIntegration::createVideoDevices()
+{
+    return new AndroidVideoDevices(this);
+}
+
+QT_END_NAMESPACE
+
+extern "C" Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void * /*reserved*/)
 {
     static bool initialized = false;
     if (initialized)
@@ -135,26 +157,10 @@ Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void * /*reserved*/)
     if (vm->GetEnv(&uenv.venv, JNI_VERSION_1_6) != JNI_OK)
         return JNI_ERR;
 
-    const auto context = QNativeInterface::QAndroidApplication::context();
-    QtJniTypes::QtMultimediaUtils::callStaticMethod<void>("setContext", context);
-
-    if (!AndroidMediaPlayer::registerNativeMethods()
-            || !AndroidCamera::registerNativeMethods()
-            || !AndroidMediaRecorder::registerNativeMethods()
-            || !AndroidSurfaceHolder::registerNativeMethods()) {
+    if (!QAndroidIntegration::registerNativeMethods())
         return JNI_ERR;
-    }
-
-    AndroidSurfaceTexture::registerNativeMethods();
 
     return JNI_VERSION_1_6;
 }
 
-QPlatformVideoDevices *QAndroidIntegration::createVideoDevices()
-{
-    return new AndroidVideoDevices(this);
-}
-
-QT_END_NAMESPACE
-
 #include "qandroidintegration.moc"
